from django.conf import settings
from geo import get_geo_info
from geo import get_ip_address
import defaults

class GeoAwareSessionMiddleware(object):
    """ Saves geo info in session if GeoIP is configured for city or country.

    geo_info = {
        'fqdn_or_ip': '',
        'city': '', 
        'continent_code': '', 
        'region': '',
        'charset': 0,
        'area_code': 0,
        'longitude': 0.0,
        'country_code3': '',
        'latitude': 0.0,
        'postal_code': None,
        'dma_code': 0,
        'country_code': '',
        'country_name': '',
    }
    """

    def process_request(self, request):
        """ Save or update geo info in session """
        fqdn_or_ip = getattr(defaults, 'GEOIP_DEBUG_DOMAIN_OR_IP', get_ip_address(request))
        try:
            if request.session['geo_info']['fqdn_or_ip'] == fqdn_or_ip:
                return None
        except:
            pass
        geo_info = get_geo_info(request)
        request.session['geo_info'] = geo_info
        request.session.modified = True
        return None



from django.conf import settings

try:
    from django.contrib.gis.geoip import GeoIP
except ImportError:
    from django.contrib.gis.utils import GeoIP

GEOIP_CACHE_METHOD = getattr(settings, 'GEOIP_CACHE_METHOD', GeoIP.GEOIP_STANDARD)
GEOIP_INCLUDE_TEMPLATE_TAGS = getattr(settings, 'GEOIP_INCLUDE_TEMPLATE_TAGS', False)

if getattr(settings, 'GEOIP_DEBUG_DOMAIN_OR_IP', ''):
    GEOIP_DEBUG_DOMAIN_OR_IP = getattr(settings, 'GEOIP_DEBUG_DOMAIN_OR_IP')



from django import template
from django.conf import settings
from ..geo import get_geo_info
from ..geo import get_ip_address

register = template.Library()

def _get_geoip_info(request):
    if 'geo_info' in request.session:
        geo_info = request.session['geo_info']
    else:
        geo_info = get_geo_info(request)
    return geo_info


@register.filter
def geo_country_name(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['country_name'])

@register.filter
def geo_country_code(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['country_code'])

@register.filter
def geo_country_code3(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['country_code3'])

@register.filter
def geo_city(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['city'])

@register.filter
def geo_latitude(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['latitude'])

@register.filter
def geo_longitude(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['longitude'])

@register.filter
def geo_postal_code(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['postal_code'])

@register.filter
def geo_region(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['region'])

@register.filter
def geo_dma_code(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['dma_code'])

@register.filter
def geo_area_code(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['area_code'])

@register.filter
def geo_fqdn_or_ip(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['fqdn_or_ip'])

@register.filter
def geo_charset(request):
    geo_info = _get_geoip_info(request)
    return(geo_info['charset'])






__version__ = '0.5.0'

import defaults

GEOIP_INCLUDE_TEMPLATE_TAGS = getattr(defaults, 'GEOIP_INCLUDE_TEMPLATE_TAGS')
if GEOIP_INCLUDE_TEMPLATE_TAGS:
    from django import template
    application_tags = [
        'geoaware.templatetags.geoaware',
    ]
    for t in application_tags: template.add_to_builtins(t)




from django.conf import settings
from geo import get_geo_info
from geo import get_ip_address

def geoaware(request):
    """ Bring GeoInfo into the context if GeoIP is configured for city or country.
    geo_info = {
        'fqdn_or_ip': '',
        'city': '', 
        'continent_code': '', 
        'region': '',
        'charset': 0,
        'area_code': 0,
        'longitude': 0.0,
        'country_code3': '',
        'latitude': 0.0,
        'postal_code': None,
        'dma_code': 0,
        'country_code': '',
        'country_name': '',
    }
    """
    cxt = {}
    geo_info = get_geo_info(request)
    cxt = {'geo_info': geo_info}
    return cxt



import re
from django.conf import settings

try:
    from django.contrib.gis.geoip import GeoIP
except ImportError:
    from django.contrib.gis.utils import GeoIP
import defaults

# by no means this is a perfect IP regex
IP_RE = re.compile('\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}')

def get_ip_address(request):
    """ Make best attempt to get client's real IP or return the loopback IP """
    
    lo = '127.0.0.1'
    get_ip = lambda x,y: request.META.get(x,y)
    ip_addr = get_ip('HTTP_X_FORWARDED_FOR', get_ip('HTTP_X_REAL_IP', get_ip('REMOTE_ADDR', lo)))
    try:
        ip_addr = IP_RE.match(ip_addr).group(0)
    except:
        ip_addr = lo
    return ip_addr


def get_geo_info(request):
    """ Get GeoInfo - Relies on Django to raise exception on improper configuration  """

    geo_info = {
        'fqdn_or_ip': '',
        'city': '', 
        'continent_code': '', 
        'region': '',
        'charset': 0,
        'area_code': 0,
        'longitude': 0.0,
        'country_code3': '',
        'latitude': 0.0,
        'postal_code': None,
        'dma_code': 0,
        'country_code': '',
        'country_name': '',
    }
    fqdn_or_ip = getattr(defaults, 'GEOIP_DEBUG_DOMAIN_OR_IP', get_ip_address(request))
    if fqdn_or_ip:
        cache_method = getattr(defaults, 'GEOIP_CACHE_METHOD')
        geo = GeoIP(cache=cache_method)
        try:
            ginfo = geo.city(fqdn_or_ip)
            geo_info.update(ginfo)
        except:
            try:
                ginfo = geo.country(fqdn_or_ip)
                geo_info.update(ginfo)
            except:
                pass
        geo_info['fqdn_or_ip'] = fqdn_or_ip

    return geo_info



